"""\
Test cases for sync2cd
Copyright (C) 2006  Remy Blank

This file is part of sync2cd.

This program is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation, version 2.

This program is distributed in the hope that it will be useful, but 
WITHOUT ANY WARRANTY; without even the implied warranty of 
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation,
Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
"""

# Module imports
from cStringIO import StringIO
from Vfs import VfsTestCase
import sync2cd

# Graft list printing
class GraftListTest(VfsTestCase):
    def testGraftPoint(self):
        "Escaping of graft point entries"
        self.assertEqual(sync2cd.GraftEscape("home/test/file1.mp3"), "home/test/file1.mp3")
        self.assertEqual(sync2cd.GraftEscape("with=equal.mp3"), "with\\=equal.mp3")
        self.assertEqual(sync2cd.GraftEscape("with\\backslash.mp3"), "with\\\\backslash.mp3")
            
    def testGraftList(self):
        "Generate a graft list"
        out = StringIO()
        sync2cd.CreateGraftList("/test_backup", 2, "/usr/local/bin/sync2cd.py", out)
        self.assertEqual(out.getvalue(), '''\
.sync2cd/sync2cd.py=/usr/local/bin/sync2cd.py
.sync2cd/test_backup=/test_backup
.sync2cd/test_backup.0002=/test_backup.0002
home/test/dir2/file7.mp3=/home/test/dir2/file7.mp3
home/test/dir3/dir3.1/file9.mp3=/home/test/dir3/dir3.1/file9.mp3
home/test/dir3/file8.mp3=/home/test/dir3/file8.mp3
home/test/file1.mp3=/home/test/file1.mp3
''')

    def testNonRootGraftList(self):
        "Generate a graft list when not in root directory"
        self.cwd = "/prefix"
        out = StringIO()
        sync2cd.CreateGraftList("/test_backup", 2, "/usr/local/bin/sync2cd.py", out)
        self.assertEqual(out.getvalue(), '''\
.sync2cd/sync2cd.py=/usr/local/bin/sync2cd.py
.sync2cd/test_backup=/test_backup
.sync2cd/test_backup.0002=/test_backup.0002
home/test/dir2/file7.mp3=/prefix/home/test/dir2/file7.mp3
home/test/dir3/dir3.1/file9.mp3=/prefix/home/test/dir3/dir3.1/file9.mp3
home/test/dir3/file8.mp3=/prefix/home/test/dir3/file8.mp3
home/test/file1.mp3=/prefix/home/test/file1.mp3
''')
